SF.net SVN: geany: [775] trunk
eht16 at users.sourceforge.net
eht16 at xxxxx
Thu Aug 31 18:26:15 UTC 2006
Revision: 775
http://svn.sourceforge.net/geany/?rev=775&view=rev
Author: eht16
Date: 2006-08-31 11:25:57 -0700 (Thu, 31 Aug 2006)
Log Message:
-----------
Improved parsing compiler messages when using the ferite compiler.
Added some primitives and improved compiler settings for Ferite.
Modified Paths:
--------------
trunk/ChangeLog
trunk/data/filetypes.ferite
trunk/src/msgwindow.c
Modified: trunk/ChangeLog
===================================================================
--- trunk/ChangeLog 2006-08-30 18:53:45 UTC (rev 774)
+++ trunk/ChangeLog 2006-08-31 18:25:57 UTC (rev 775)
@@ -1,3 +1,10 @@
+2006-08-31 Enrico Tröger <enrico.troeger at uvena.de>
+
+ * src/msgwindow.c, data/filetypes.ferite:
+ Improved parsing compiler messages when using the ferite compiler.
+ Added some primitives and improved compiler settings for Ferite.
+
+
2006-08-30 Enrico Tröger <enrico.troeger at uvena.de>
* configure.in, src/callbacks.c, src/geany.h, src/main.c:
Modified: trunk/data/filetypes.ferite
===================================================================
--- trunk/data/filetypes.ferite 2006-08-30 18:53:45 UTC (rev 774)
+++ trunk/data/filetypes.ferite 2006-08-31 18:25:57 UTC (rev 775)
@@ -24,12 +24,12 @@
[keywords]
# all items must be in one line
primary=false null self super true abstract alias arguments attribute_missing break case class closure conformsToProtocol constructor default deliver destructor diliver do else extends final fix for function if iferr implements include instanceof method_missing modifies namespace new private protected protocol public recipient rename return static switch uses using while
-types=string number array object void
-docComment=@brief @class @declaration @description @end @example @extends @function @group @implements @modifies @module @namespace @param @protocol @return @return @static @type @variable @warning
+types=string number array object void XML Unix Sys String Stream Serialize RMI Posix Number Network Math FileSystem Console Array
+docComment=brief class declaration description end example extends function group implements modifies module namespace param protocol return return static type variable warning
[settings]
# the following characters are these which a "word" can contains, see documentation
-wordchars=_#&abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
+wordchars=@_abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ0123456789
# if only single comment char is supported like # in this file, leave comment_close blank
comment_open=//
@@ -50,5 +50,5 @@
# %f will be replaced by the complete filename
# %e will be replaced by the filename without extension
# (use only one of it at one time)
-compiler=ferite -c "%f"
+compiler=ferite -vc "%f"
run_cmd=ferite "%f"
Modified: trunk/src/msgwindow.c
===================================================================
--- trunk/src/msgwindow.c 2006-08-30 18:53:45 UTC (rev 774)
+++ trunk/src/msgwindow.c 2006-08-31 18:25:57 UTC (rev 775)
@@ -417,11 +417,22 @@
}
case GEANY_FILETYPES_FERITE:
{
- // Error: Parse Error: on line 5 in "/misc/tmp/testfiles_geany/hello.fe"
- pattern = " \"";
- field_min_len = 10;
- field_idx_line = 5;
- field_idx_file = 8;
+ // Error: Parse Error: on line 5 in "/tmp/hello.fe"
+ // Error: Compile Error: on line 24, in /test/class.fe
+ if (strncmp(string, "Error: Compile Error", 20) == 0)
+ {
+ pattern = " ";
+ field_min_len = 8;
+ field_idx_line = 5;
+ field_idx_file = 7;
+ }
+ else
+ {
+ pattern = " \"";
+ field_min_len = 10;
+ field_idx_line = 5;
+ field_idx_file = 8;
+ }
break;
}
This was sent by the SourceForge.net collaborative development platform, the world's largest Open Source development site.
More information about the Commits
mailing list